unit Palettes;

interface
uses Graphics;

const NumPalettes=3;
      PaletteGranularity=16;

type str31=string[31];

type TColorRec=record
                 R,G,B:byte;
                 Col:TColor;
                 Name:str31;
               end;
     TPalette=object
                Name:str31;
                Entries:integer;
                DataSize:integer;
                Data:array of TColorRec;
                procedure Init(const NewName:string);
                procedure Add(_R,_G,_B:integer;const _Name:string);
                procedure Replace(Index:integer;_r,_g,_b:integer;const _name:string);
                procedure Remove(Index:integer);
                procedure LoadFromFile(const FileName:string);
                procedure SaveToFile(const FileName:string);
              end;

var PalData:array[0..(NumPalettes-1)]of TPalette;

implementation

procedure TPalette.Init(const NewName:string);
begin
  Name:=NewName;
  Entries:=0;
  DataSize:=PaletteGranularity;
  SetLength(Data,DataSize);
end;

procedure TPalette.Add(_R,_G,_B:integer;const _Name:string);
begin
  inc(Entries);
  if Entries>DataSize then begin
    while Entries>DataSize do inc(DataSize,PaletteGranularity);
    SetLength(Data,DataSize);
  end;
  Replace(Entries-1,_R,_G,_B,_Name);
end;

procedure TPalette.Replace(Index:integer;_r,_g,_b:integer;const _name:string);
begin
  with Data[Index] do begin
    R:=_r;G:=_g;B:=_b;
    Col:=(_b SHL 16) OR (_g SHL 8) OR _r;
    Name:=_name;
  end;
end;

procedure TPalette.Remove(Index:integer);
var Count:integer;
begin
  if (Index>=Entries) OR (Index<0) then exit;
  dec(Entries);
  if Index<Entries then
    for Count:=(Index+1) to Entries do
      Data[Count-1]:=Data[Count];
end;

procedure TPalette.LoadFromFile(const FileName:string);
var F:System.Text;
    s:string; p,l:integer;
    tR,tG,tB:byte; tN:str31;
procedure skipspaces;begin
  if p>l then exit;
  while (p<=l) AND ((s[p]=#32) OR (s[p]=#9)) do inc(p);end;
procedure getnumber(var no:byte);begin no:=0;
  if p>l then exit;
  while (p<=l) AND (s[p]>='0') AND (s[p]<='9') do
  begin no:=10*no+byte(s[p])-48;inc(p);end;end;
begin
  AssignFile(F,FileName);
  {$I-} Reset(F); {$I+}
  if IOresult<>0 then exit;
  while not EOF(F) do begin
    readln(F,s);
    l:=length(s);
    p:=1;
    skipspaces;getnumber(tR);
    skipspaces;getnumber(tG);
    skipspaces;getnumber(tB);
    skipspaces;
    if p<=l then begin
      tN:=copy(s,p,31);
      Add(tR,tG,tB,tN);
    end;
  end;
  CloseFile(F);
end;

procedure TPalette.SaveToFile(const FileName:string);
var F:System.Text;
    Count:integer;
begin
  AssignFile(F,FileName);
  {$I-} Rewrite(F); {$I+}
  if IOresult<>0 then exit;
  for Count:=1 to Entries do
    with Data[Count-1] do
      writeln(F,R:3,G:4,B:4,'  ',Name);
  CloseFile(F);
end;

begin
  with PalData[0] do begin
    Init('Benutzerdefiniert');
  end;
  with PalData[1] do begin
    Init('Standardfarben');
    Add($00,$00,$00,'Schwarz');
    Add($20,$20,$20,'Grau 12,5% [32]');
    Add($40,$40,$40,'Grau 25% [64]');
    Add($60,$60,$60,'Grau 37,5% [96]');
    Add($80,$80,$80,'Grau 50% [128]');
    Add($A0,$A0,$A0,'Grau 62,5% [160]');
    Add($C0,$C0,$C0,'Grau 75% [192]');
    Add($E0,$E0,$E0,'Grau 87,5% [224]');
    Add($FF,$FF,$FF,'Wei');
    Add($40,$00,$00,'Rot 25% [64:0]');
    Add($80,$00,$00,'Rot 50% [128:0]');
    Add($C0,$00,$00,'Rot 75% [192:0]');
    Add($FF,$00,$00,'Rot (rein) [255:0]');
    Add($FF,$40,$40,'Rot Pastell 25% [255:64]');
    Add($FF,$80,$80,'Rot Pastell 50% [255:128]');
    Add($FF,$C0,$C0,'Rot Pastell 75% [255:192]');
    Add($40,$40,$00,'Gelb 25% [64:0]');
    Add($80,$80,$00,'Gelb 50% [128:0]');
    Add($C0,$C0,$00,'Gelb 75% [192:0]');
    Add($FF,$FF,$00,'Gelb (rein) [255:0]');
    Add($FF,$FF,$40,'Gelb Pastell 25% [255:64]');
    Add($FF,$FF,$80,'Gelb Pastell 50% [255:128]');
    Add($FF,$FF,$C0,'Gelb Pastell 75% [255:192]');
    Add($00,$40,$00,'Grn 25% [64:0]');
    Add($00,$80,$00,'Grn 50% [128:0]');
    Add($00,$C0,$00,'Grn 75% [192:0]');
    Add($00,$FF,$00,'Grn (rein) [255:0]');
    Add($40,$FF,$40,'Grn Pastell 25% [255:64]');
    Add($80,$FF,$80,'Grn Pastell 50% [255:128]');
    Add($C0,$FF,$C0,'Grn Pastell 75% [255:192]');
    Add($00,$40,$40,'Cyan 25% [64:0]');
    Add($00,$80,$80,'Cyan 50% [128:0]');
    Add($00,$C0,$C0,'Cyan 75% [192:0]');
    Add($00,$FF,$FF,'Cyan (rein) [255:0]');
    Add($40,$FF,$FF,'Cyan Pastell 25% [255:64]');
    Add($80,$FF,$FF,'Cyan Pastell 50% [255:128]');
    Add($C0,$FF,$FF,'Cyan Pastell 75% [255:192]');
    Add($00,$00,$40,'Blau 25% [64:0]');
    Add($00,$00,$80,'Blau 50% [128:0]');
    Add($00,$00,$C0,'Blau 75% [192:0]');
    Add($00,$00,$FF,'Blau (rein) [255:0]');
    Add($40,$40,$FF,'Blau Pastell 25% [255:64]');
    Add($80,$80,$FF,'Blau Pastell 50% [255:128]');
    Add($C0,$C0,$FF,'Blau Pastell 75% [255:192]');
    Add($40,$00,$40,'Magenta 25% [64:0]');
    Add($80,$00,$80,'Magenta 50% [128:0]');
    Add($C0,$00,$C0,'Magenta 75% [192:0]');
    Add($FF,$00,$FF,'Magenta (rein) [255:0]');
    Add($FF,$40,$FF,'Magenta Pastell 25% [255:64]');
    Add($FF,$80,$FF,'Magenta Pastell 50% [255:128]');
    Add($FF,$C0,$FF,'Magenta Pastell 75% [255:192]');
  end;
  with PalData[2] do begin
    Init('X-Farben');
    Add(0,0,0,'gray0');
    Add(3,3,3,'gray1');
    Add(5,5,5,'gray2');
    Add(8,8,8,'gray3');
    Add(10,10,10,'gray4');
    Add(13,13,13,'gray5');
    Add(15,15,15,'gray6');
    Add(18,18,18,'gray7');
    Add(20,20,20,'gray8');
    Add(23,23,23,'gray9');
    Add(26,26,26,'gray10');
    Add(28,28,28,'gray11');
    Add(31,31,31,'gray12');
    Add(33,33,33,'gray13');
    Add(36,36,36,'gray14');
    Add(38,38,38,'gray15');
    Add(41,41,41,'gray16');
    Add(43,43,43,'gray17');
    Add(46,46,46,'gray18');
    Add(48,48,48,'gray19');
    Add(51,51,51,'gray20');
    Add(54,54,54,'gray21');
    Add(56,56,56,'gray22');
    Add(59,59,59,'gray23');
    Add(61,61,61,'gray24');
    Add(64,64,64,'gray25');
    Add(66,66,66,'gray26');
    Add(69,69,69,'gray27');
    Add(71,71,71,'gray28');
    Add(74,74,74,'gray29');
    Add(77,77,77,'gray30');
    Add(79,79,79,'gray31');
    Add(82,82,82,'gray32');
    Add(84,84,84,'gray33');
    Add(87,87,87,'gray34');
    Add(89,89,89,'gray35');
    Add(92,92,92,'gray36');
    Add(94,94,94,'gray37');
    Add(97,97,97,'gray38');
    Add(99,99,99,'gray39');
    Add(102,102,102,'gray40');
    Add(105,105,105,'gray41');
    Add(107,107,107,'gray42');
    Add(110,110,110,'gray43');
    Add(112,112,112,'gray44');
    Add(115,115,115,'gray45');
    Add(117,117,117,'gray46');
    Add(120,120,120,'gray47');
    Add(122,122,122,'gray48');
    Add(125,125,125,'gray49');
    Add(127,127,127,'gray50');
    Add(130,130,130,'gray51');
    Add(133,133,133,'gray52');
    Add(135,135,135,'gray53');
    Add(138,138,138,'gray54');
    Add(140,140,140,'gray55');
    Add(143,143,143,'gray56');
    Add(145,145,145,'gray57');
    Add(148,148,148,'gray58');
    Add(150,150,150,'gray59');
    Add(153,153,153,'gray60');
    Add(156,156,156,'gray61');
    Add(158,158,158,'gray62');
    Add(161,161,161,'gray63');
    Add(163,163,163,'gray64');
    Add(166,166,166,'gray65');
    Add(168,168,168,'gray66');
    Add(171,171,171,'gray67');
    Add(173,173,173,'gray68');
    Add(176,176,176,'gray69');
    Add(179,179,179,'gray70');
    Add(181,181,181,'gray71');
    Add(184,184,184,'gray72');
    Add(186,186,186,'gray73');
    Add(189,189,189,'gray74');
    Add(191,191,191,'gray75');
    Add(194,194,194,'gray76');
    Add(196,196,196,'gray77');
    Add(199,199,199,'gray78');
    Add(201,201,201,'gray79');
    Add(204,204,204,'gray80');
    Add(207,207,207,'gray81');
    Add(209,209,209,'gray82');
    Add(212,212,212,'gray83');
    Add(214,214,214,'gray84');
    Add(217,217,217,'gray85');
    Add(219,219,219,'gray86');
    Add(222,222,222,'gray87');
    Add(224,224,224,'gray88');
    Add(227,227,227,'gray89');
    Add(229,229,229,'gray90');
    Add(232,232,232,'gray91');
    Add(235,235,235,'gray92');
    Add(237,237,237,'gray93');
    Add(240,240,240,'gray94');
    Add(242,242,242,'gray95');
    Add(245,245,245,'gray96');
    Add(247,247,247,'gray97');
    Add(250,250,250,'gray98');
    Add(252,252,252,'gray99');
    Add(255,255,255,'gray100');
    Add(169,169,169,'dark gray');
    Add(0,0,139,'dark blue');
    Add(0,139,139,'dark cyan');
    Add(139,0,139,'dark magenta');
    Add(139,0,0,'dark red');
    Add(144,238,144,'light green');
    Add(255,250,250,'snow');
    Add(248,248,255,'ghost white');
    Add(245,245,245,'white smoke');
    Add(220,220,220,'gainsboro');
    Add(255,250,240,'floral white');
    Add(253,245,230,'old lace');
    Add(250,240,230,'linen');
    Add(250,235,215,'antique white');
    Add(255,239,213,'papaya whip');
    Add(255,235,205,'blanched almond');
    Add(255,228,196,'bisque');
    Add(255,218,185,'peach puff');
    Add(255,222,173,'navajo white');
    Add(255,228,181,'moccasin');
    Add(255,248,220,'cornsilk');
    Add(255,255,240,'ivory');
    Add(255,250,205,'lemon chiffon');
    Add(255,245,238,'seashell');
    Add(240,255,240,'honeydew');
    Add(245,255,250,'mint cream');
    Add(240,255,255,'azure');
    Add(240,248,255,'alice blue');
    Add(230,230,250,'lavender');
    Add(255,240,245,'lavender blush');
    Add(255,228,225,'misty rose');
    Add(255,255,255,'white');
    Add(0,0,0,'black');
    Add(47,79,79,'dark slate gray');
    Add(105,105,105,'dim gray');
    Add(112,128,144,'slate gray');
    Add(119,136,153,'light slate gray');
    Add(190,190,190,'gray');
    Add(211,211,211,'light gray');
    Add(25,25,112,'midnight blue');
    Add(0,0,128,'navy');
    Add(0,0,128,'navy blue');
    Add(100,149,237,'cornflower blue');
    Add(72,61,139,'dark slate blue');
    Add(106,90,205,'slate blue');
    Add(123,104,238,'medium slate blue');
    Add(132,112,255,'light slate blue');
    Add(0,0,205,'medium blue');
    Add(65,105,225,'royal blue');
    Add(0,0,255,'blue');
    Add(30,144,255,'dodger blue');
    Add(0,191,255,'deep sky blue');
    Add(135,206,235,'sky blue');
    Add(135,206,250,'light sky blue');
    Add(70,130,180,'steel blue');
    Add(176,196,222,'light steel blue');
    Add(173,216,230,'light blue');
    Add(176,224,230,'powder blue');
    Add(175,238,238,'pale turquoise');
    Add(0,206,209,'dark turquoise');
    Add(72,209,204,'medium turquoise');
    Add(64,224,208,'turquoise');
    Add(0,255,255,'cyan');
    Add(224,255,255,'light cyan');
    Add(95,158,160,'cadet blue');
    Add(102,205,170,'medium aquamarine');
    Add(127,255,212,'aquamarine');
    Add(0,100,0,'dark green');
    Add(85,107,47,'dark olive green');
    Add(143,188,143,'dark sea green');
    Add(46,139,87,'sea green');
    Add(60,179,113,'medium sea green');
    Add(32,178,170,'light sea green');
    Add(152,251,152,'pale green');
    Add(0,255,127,'spring green');
    Add(124,252,0,'lawn green');
    Add(0,255,0,'green');
    Add(127,255,0,'chartreuse');
    Add(0,250,154,'medium spring green');
    Add(173,255,47,'green yellow');
    Add(50,205,50,'lime green');
    Add(154,205,50,'yellow green');
    Add(34,139,34,'forest green');
    Add(107,142,35,'olive drab');
    Add(189,183,107,'dark khaki');
    Add(240,230,140,'khaki');
    Add(238,232,170,'pale goldenrod');
    Add(250,250,210,'light goldenrod yellow');
    Add(255,255,224,'light yellow');
    Add(255,255,0,'yellow');
    Add(255,215,0,'gold');
    Add(238,221,130,'light goldenrod');
    Add(218,165,32,'goldenrod');
    Add(184,134,11,'dark goldenrod');
    Add(188,143,143,'rosy brown');
    Add(205,92,92,'indian red');
    Add(139,69,19,'saddle brown');
    Add(160,82,45,'sienna');
    Add(205,133,63,'peru');
    Add(222,184,135,'burlywood');
    Add(245,245,220,'beige');
    Add(245,222,179,'wheat');
    Add(244,164,96,'sandy brown');
    Add(210,180,140,'tan');
    Add(210,105,30,'chocolate');
    Add(178,34,34,'firebrick');
    Add(165,42,42,'brown');
    Add(233,150,122,'dark salmon');
    Add(250,128,114,'salmon');
    Add(255,160,122,'light salmon');
    Add(255,165,0,'orange');
    Add(255,140,0,'dark orange');
    Add(255,127,80,'coral');
    Add(240,128,128,'light coral');
    Add(255,99,71,'tomato');
    Add(255,69,0,'orange red');
    Add(255,0,0,'red');
    Add(255,105,180,'hot pink');
    Add(255,20,147,'deep pink');
    Add(255,192,203,'pink');
    Add(255,182,193,'light pink');
    Add(219,112,147,'pale violet red');
    Add(176,48,96,'maroon');
    Add(199,21,133,'medium violet red');
    Add(208,32,144,'violet red');
    Add(255,0,255,'magenta');
    Add(238,130,238,'violet');
    Add(221,160,221,'plum');
    Add(218,112,214,'orchid');
    Add(186,85,211,'medium orchid');
    Add(153,50,204,'dark orchid');
    Add(148,0,211,'dark violet');
    Add(138,43,226,'blue violet');
    Add(160,32,240,'purple');
    Add(147,112,219,'medium purple');
    Add(216,191,216,'thistle');
    Add(255,250,250,'snow1');
    Add(238,233,233,'snow2');
    Add(205,201,201,'snow3');
    Add(139,137,137,'snow4');
    Add(255,245,238,'seashell1');
    Add(238,229,222,'seashell2');
    Add(205,197,191,'seashell3');
    Add(139,134,130,'seashell4');
    Add(255,239,219,'AntiqueWhite1');
    Add(238,223,204,'AntiqueWhite2');
    Add(205,192,176,'AntiqueWhite3');
    Add(139,131,120,'AntiqueWhite4');
    Add(255,228,196,'bisque1');
    Add(238,213,183,'bisque2');
    Add(205,183,158,'bisque3');
    Add(139,125,107,'bisque4');
    Add(255,218,185,'PeachPuff1');
    Add(238,203,173,'PeachPuff2');
    Add(205,175,149,'PeachPuff3');
    Add(139,119,101,'PeachPuff4');
    Add(255,222,173,'NavajoWhite1');
    Add(238,207,161,'NavajoWhite2');
    Add(205,179,139,'NavajoWhite3');
    Add(139,121,94,'NavajoWhite4');
    Add(255,250,205,'LemonChiffon1');
    Add(238,233,191,'LemonChiffon2');
    Add(205,201,165,'LemonChiffon3');
    Add(139,137,112,'LemonChiffon4');
    Add(255,248,220,'cornsilk1');
    Add(238,232,205,'cornsilk2');
    Add(205,200,177,'cornsilk3');
    Add(139,136,120,'cornsilk4');
    Add(255,255,240,'ivory1');
    Add(238,238,224,'ivory2');
    Add(205,205,193,'ivory3');
    Add(139,139,131,'ivory4');
    Add(240,255,240,'honeydew1');
    Add(224,238,224,'honeydew2');
    Add(193,205,193,'honeydew3');
    Add(131,139,131,'honeydew4');
    Add(255,240,245,'LavenderBlush1');
    Add(238,224,229,'LavenderBlush2');
    Add(205,193,197,'LavenderBlush3');
    Add(139,131,134,'LavenderBlush4');
    Add(255,228,225,'MistyRose1');
    Add(238,213,210,'MistyRose2');
    Add(205,183,181,'MistyRose3');
    Add(139,125,123,'MistyRose4');
    Add(240,255,255,'azure1');
    Add(224,238,238,'azure2');
    Add(193,205,205,'azure3');
    Add(131,139,139,'azure4');
    Add(131,111,255,'SlateBlue1');
    Add(122,103,238,'SlateBlue2');
    Add(105,89,205,'SlateBlue3');
    Add(71,60,139,'SlateBlue4');
    Add(72,118,255,'RoyalBlue1');
    Add(67,110,238,'RoyalBlue2');
    Add(58,95,205,'RoyalBlue3');
    Add(39,64,139,'RoyalBlue4');
    Add(0,0,255,'blue1');
    Add(0,0,238,'blue2');
    Add(0,0,205,'blue3');
    Add(0,0,139,'blue4');
    Add(30,144,255,'DodgerBlue1');
    Add(28,134,238,'DodgerBlue2');
    Add(24,116,205,'DodgerBlue3');
    Add(16,78,139,'DodgerBlue4');
    Add(99,184,255,'SteelBlue1');
    Add(92,172,238,'SteelBlue2');
    Add(79,148,205,'SteelBlue3');
    Add(54,100,139,'SteelBlue4');
    Add(0,191,255,'DeepSkyBlue1');
    Add(0,178,238,'DeepSkyBlue2');
    Add(0,154,205,'DeepSkyBlue3');
    Add(0,104,139,'DeepSkyBlue4');
    Add(135,206,255,'SkyBlue1');
    Add(126,192,238,'SkyBlue2');
    Add(108,166,205,'SkyBlue3');
    Add(74,112,139,'SkyBlue4');
    Add(176,226,255,'LightSkyBlue1');
    Add(164,211,238,'LightSkyBlue2');
    Add(141,182,205,'LightSkyBlue3');
    Add(96,123,139,'LightSkyBlue4');
    Add(198,226,255,'SlateGray1');
    Add(185,211,238,'SlateGray2');
    Add(159,182,205,'SlateGray3');
    Add(108,123,139,'SlateGray4');
    Add(202,225,255,'LightSteelBlue1');
    Add(188,210,238,'LightSteelBlue2');
    Add(162,181,205,'LightSteelBlue3');
    Add(110,123,139,'LightSteelBlue4');
    Add(191,239,255,'LightBlue1');
    Add(178,223,238,'LightBlue2');
    Add(154,192,205,'LightBlue3');
    Add(104,131,139,'LightBlue4');
    Add(224,255,255,'LightCyan1');
    Add(209,238,238,'LightCyan2');
    Add(180,205,205,'LightCyan3');
    Add(122,139,139,'LightCyan4');
    Add(187,255,255,'PaleTurquoise1');
    Add(174,238,238,'PaleTurquoise2');
    Add(150,205,205,'PaleTurquoise3');
    Add(102,139,139,'PaleTurquoise4');
    Add(152,245,255,'CadetBlue1');
    Add(142,229,238,'CadetBlue2');
    Add(122,197,205,'CadetBlue3');
    Add(83,134,139,'CadetBlue4');
    Add(0,245,255,'turquoise1');
    Add(0,229,238,'turquoise2');
    Add(0,197,205,'turquoise3');
    Add(0,134,139,'turquoise4');
    Add(0,255,255,'cyan1');
    Add(0,238,238,'cyan2');
    Add(0,205,205,'cyan3');
    Add(0,139,139,'cyan4');
    Add(151,255,255,'DarkSlateGray1');
    Add(141,238,238,'DarkSlateGray2');
    Add(121,205,205,'DarkSlateGray3');
    Add(82,139,139,'DarkSlateGray4');
    Add(127,255,212,'aquamarine1');
    Add(118,238,198,'aquamarine2');
    Add(102,205,170,'aquamarine3');
    Add(69,139,116,'aquamarine4');
    Add(193,255,193,'DarkSeaGreen1');
    Add(180,238,180,'DarkSeaGreen2');
    Add(155,205,155,'DarkSeaGreen3');
    Add(105,139,105,'DarkSeaGreen4');
    Add(84,255,159,'SeaGreen1');
    Add(78,238,148,'SeaGreen2');
    Add(67,205,128,'SeaGreen3');
    Add(46,139,87,'SeaGreen4');
    Add(154,255,154,'PaleGreen1');
    Add(144,238,144,'PaleGreen2');
    Add(124,205,124,'PaleGreen3');
    Add(84,139,84,'PaleGreen4');
    Add(0,255,127,'SpringGreen1');
    Add(0,238,118,'SpringGreen2');
    Add(0,205,102,'SpringGreen3');
    Add(0,139,69,'SpringGreen4');
    Add(0,255,0,'green1');
    Add(0,238,0,'green2');
    Add(0,205,0,'green3');
    Add(0,139,0,'green4');
    Add(127,255,0,'chartreuse1');
    Add(118,238,0,'chartreuse2');
    Add(102,205,0,'chartreuse3');
    Add(69,139,0,'chartreuse4');
    Add(192,255,62,'OliveDrab1');
    Add(179,238,58,'OliveDrab2');
    Add(154,205,50,'OliveDrab3');
    Add(105,139,34,'OliveDrab4');
    Add(202,255,112,'DarkOliveGreen1');
    Add(188,238,104,'DarkOliveGreen2');
    Add(162,205,90,'DarkOliveGreen3');
    Add(110,139,61,'DarkOliveGreen4');
    Add(255,246,143,'khaki1');
    Add(238,230,133,'khaki2');
    Add(205,198,115,'khaki3');
    Add(139,134,78,'khaki4');
    Add(255,236,139,'LightGoldenrod1');
    Add(238,220,130,'LightGoldenrod2');
    Add(205,190,112,'LightGoldenrod3');
    Add(139,129,76,'LightGoldenrod4');
    Add(255,255,224,'LightYellow1');
    Add(238,238,209,'LightYellow2');
    Add(205,205,180,'LightYellow3');
    Add(139,139,122,'LightYellow4');
    Add(255,255,0,'yellow1');
    Add(238,238,0,'yellow2');
    Add(205,205,0,'yellow3');
    Add(139,139,0,'yellow4');
    Add(255,215,0,'gold1');
    Add(238,201,0,'gold2');
    Add(205,173,0,'gold3');
    Add(139,117,0,'gold4');
    Add(255,193,37,'goldenrod1');
    Add(238,180,34,'goldenrod2');
    Add(205,155,29,'goldenrod3');
    Add(139,105,20,'goldenrod4');
    Add(255,185,15,'DarkGoldenrod1');
    Add(238,173,14,'DarkGoldenrod2');
    Add(205,149,12,'DarkGoldenrod3');
    Add(139,101,8,'DarkGoldenrod4');
    Add(255,193,193,'RosyBrown1');
    Add(238,180,180,'RosyBrown2');
    Add(205,155,155,'RosyBrown3');
    Add(139,105,105,'RosyBrown4');
    Add(255,106,106,'IndianRed1');
    Add(238,99,99,'IndianRed2');
    Add(205,85,85,'IndianRed3');
    Add(139,58,58,'IndianRed4');
    Add(255,130,71,'sienna1');
    Add(238,121,66,'sienna2');
    Add(205,104,57,'sienna3');
    Add(139,71,38,'sienna4');
    Add(255,211,155,'burlywood1');
    Add(238,197,145,'burlywood2');
    Add(205,170,125,'burlywood3');
    Add(139,115,85,'burlywood4');
    Add(255,231,186,'wheat1');
    Add(238,216,174,'wheat2');
    Add(205,186,150,'wheat3');
    Add(139,126,102,'wheat4');
    Add(255,165,79,'tan1');
    Add(238,154,73,'tan2');
    Add(205,133,63,'tan3');
    Add(139,90,43,'tan4');
    Add(255,127,36,'chocolate1');
    Add(238,118,33,'chocolate2');
    Add(205,102,29,'chocolate3');
    Add(139,69,19,'chocolate4');
    Add(255,48,48,'firebrick1');
    Add(238,44,44,'firebrick2');
    Add(205,38,38,'firebrick3');
    Add(139,26,26,'firebrick4');
    Add(255,64,64,'brown1');
    Add(238,59,59,'brown2');
    Add(205,51,51,'brown3');
    Add(139,35,35,'brown4');
    Add(255,140,105,'salmon1');
    Add(238,130,98,'salmon2');
    Add(205,112,84,'salmon3');
    Add(139,76,57,'salmon4');
    Add(255,160,122,'LightSalmon1');
    Add(238,149,114,'LightSalmon2');
    Add(205,129,98,'LightSalmon3');
    Add(139,87,66,'LightSalmon4');
    Add(255,165,0,'orange1');
    Add(238,154,0,'orange2');
    Add(205,133,0,'orange3');
    Add(139,90,0,'orange4');
    Add(255,127,0,'DarkOrange1');
    Add(238,118,0,'DarkOrange2');
    Add(205,102,0,'DarkOrange3');
    Add(139,69,0,'DarkOrange4');
    Add(255,114,86,'coral1');
    Add(238,106,80,'coral2');
    Add(205,91,69,'coral3');
    Add(139,62,47,'coral4');
    Add(255,99,71,'tomato1');
    Add(238,92,66,'tomato2');
    Add(205,79,57,'tomato3');
    Add(139,54,38,'tomato4');
    Add(255,69,0,'OrangeRed1');
    Add(238,64,0,'OrangeRed2');
    Add(205,55,0,'OrangeRed3');
    Add(139,37,0,'OrangeRed4');
    Add(255,0,0,'red1');
    Add(238,0,0,'red2');
    Add(205,0,0,'red3');
    Add(139,0,0,'red4');
    Add(255,20,147,'DeepPink1');
    Add(238,18,137,'DeepPink2');
    Add(205,16,118,'DeepPink3');
    Add(139,10,80,'DeepPink4');
    Add(255,110,180,'HotPink1');
    Add(238,106,167,'HotPink2');
    Add(205,96,144,'HotPink3');
    Add(139,58,98,'HotPink4');
    Add(255,181,197,'pink1');
    Add(238,169,184,'pink2');
    Add(205,145,158,'pink3');
    Add(139,99,108,'pink4');
    Add(255,174,185,'LightPink1');
    Add(238,162,173,'LightPink2');
    Add(205,140,149,'LightPink3');
    Add(139,95,101,'LightPink4');
    Add(255,130,171,'PaleVioletRed1');
    Add(238,121,159,'PaleVioletRed2');
    Add(205,104,137,'PaleVioletRed3');
    Add(139,71,93,'PaleVioletRed4');
    Add(255,52,179,'maroon1');
    Add(238,48,167,'maroon2');
    Add(205,41,144,'maroon3');
    Add(139,28,98,'maroon4');
    Add(255,62,150,'VioletRed1');
    Add(238,58,140,'VioletRed2');
    Add(205,50,120,'VioletRed3');
    Add(139,34,82,'VioletRed4');
    Add(255,0,255,'magenta1');
    Add(238,0,238,'magenta2');
    Add(205,0,205,'magenta3');
    Add(139,0,139,'magenta4');
    Add(255,131,250,'orchid1');
    Add(238,122,233,'orchid2');
    Add(205,105,201,'orchid3');
    Add(139,71,137,'orchid4');
    Add(255,187,255,'plum1');
    Add(238,174,238,'plum2');
    Add(205,150,205,'plum3');
    Add(139,102,139,'plum4');
    Add(224,102,255,'MediumOrchid1');
    Add(209,95,238,'MediumOrchid2');
    Add(180,82,205,'MediumOrchid3');
    Add(122,55,139,'MediumOrchid4');
    Add(191,62,255,'DarkOrchid1');
    Add(178,58,238,'DarkOrchid2');
    Add(154,50,205,'DarkOrchid3');
    Add(104,34,139,'DarkOrchid4');
    Add(155,48,255,'purple1');
    Add(145,44,238,'purple2');
    Add(125,38,205,'purple3');
    Add(85,26,139,'purple4');
    Add(171,130,255,'MediumPurple1');
    Add(159,121,238,'MediumPurple2');
    Add(137,104,205,'MediumPurple3');
    Add(93,71,139,'MediumPurple4');
    Add(255,225,255,'thistle1');
    Add(238,210,238,'thistle2');
    Add(205,181,205,'thistle3');
    Add(139,123,139,'thistle4');
  end;
end.
