unit ScreenShot;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ToolWin, ComCtrls, StdCtrls, ImgList, Buttons;

type TToolMode=(Hand,Zoom,Pick);

type
  TScreenShotForm = class(TForm)
    ToolBar1: TToolBar;
    mZoom: TToolButton;
    HScroll: TScrollBar;
    VScroll: TScrollBar;
    mHand: TToolButton;
    mPick: TToolButton;
    ImageList1: TImageList;
    ToolButton1: TToolButton;
    SaveImage: TToolButton;
    SaveDialog: TSaveDialog;
    ShowOverview: TSpeedButton;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormPaint(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure VScrollScroll(Sender: TObject; ScrollCode: TScrollCode;
      var ScrollPos: Integer);
    procedure HScrollScroll(Sender: TObject; ScrollCode: TScrollCode;
      var ScrollPos: Integer);
    procedure FormMouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure FormMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure mHandClick(Sender: TObject);
    procedure mZoomClick(Sender: TObject);
    procedure mPickClick(Sender: TObject);
    procedure FormMouseUp(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FormKeyPress(Sender: TObject; var Key: Char);
    procedure SaveImageClick(Sender: TObject);
    procedure ShowOverviewMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure ShowOverviewMouseUp(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
  private
    { Private-Deklarationen}
    ToolMode:TToolMode;
    WasMouseDown:boolean;
    ScrWidth,ScrHeight:integer;
    VisWidth,VisHeight:integer;
    ZoomMul,ZoomDiv:integer;
    MaxX,MaxY:integer;
    HandBaseX,HandBaseY:integer;
    procedure Redraw;
    procedure ReFit;
  public
    { Public-Deklarationen}
    Shot:TBitmap;
    StartX,StartY:integer;
    OrgWidth,OrgHeight:integer;
  end;

var
  ScreenShotForm: TScreenShotForm;

implementation

uses Main, Overview;

{$R *.DFM}

procedure TScreenShotForm.FormCreate(Sender: TObject);
var Desktop:TCanvas;
    Area:TRect;
begin
  ScrWidth:=Screen.Width;
  ScrHeight:=Screen.Height;
  Area:=Rect(0,0,ScrWidth,ScrHeight);
  Shot:=TBitmap.Create;
  with Shot do begin
    PixelFormat:=pfDevice;
    Width:=ScrWidth;
    Height:=ScrHeight;
  end;
  Desktop:=TCanvas.Create;
  Desktop.Handle:=GetDC(0);
  Shot.Canvas.CopyRect(Area,Desktop,Area);
  ReleaseDC(0,Desktop.Handle);
  Desktop.Free;

  WasMouseDown:=false;
  ToolMode:=Pick;
  StartX:=0;StartY:=0;
  ZoomMul:=1;ZoomDiv:=1;
end;

procedure TScreenShotForm.FormDestroy(Sender: TObject);
begin
  Shot.Free;
end;

procedure TScreenShotForm.Redraw;
var EndX,EndY:integer;
begin
  EndX:=StartX+OrgWidth;  if EndX>ScrWidth  then EndX:=ScrWidth;
  EndY:=StartY+OrgHeight; if EndY>ScrHeight then EndY:=ScrHeight;
  Canvas.CopyRect(Rect(0,25,VisWidth,25+VisHeight),Shot.Canvas,
                  Rect(StartX,StartY,EndX,EndY));
end;

procedure TScreenShotForm.FormPaint(Sender: TObject);
begin
  Redraw;
end;

procedure TScreenShotForm.FormResize(Sender: TObject);
begin
  VisWidth:=ClientWidth-17;
  VisHeight:=ClientHeight-42;
  ReFit;
end;

procedure TScreenShotForm.ReFit;
begin
  OrgWidth:=VisWidth*ZoomDiv DIV ZoomMul;
  OrgHeight:=VisHeight*ZoomDiv DIV ZoomMul;
  MaxX:=ScrWidth-OrgWidth+1;
  MaxY:=ScrHeight-OrgHeight+1;
  if MaxX<0 then MaxX:=0;
  if MaxY<0 then MaxY:=0;
  if StartX>MaxX then StartX:=MaxX;
  if StartY>MaxY then StartY:=MaxY;
  with HScroll do begin
    Max:=MaxX; Position:=StartX;
  end;
  with VScroll do begin
    Max:=MaxY; Position:=StartY;
  end;
  Caption:='Screenshot-Ansicht ('+IntToStr(ZoomMul)+':'+IntToStr(ZoomDiv)+')';
  Redraw;
end;

procedure TScreenShotForm.VScrollScroll(Sender: TObject;
  ScrollCode: TScrollCode; var ScrollPos: Integer);
begin
  StartY:=ScrollPos;
  Redraw;
end;

procedure TScreenShotForm.HScrollScroll(Sender: TObject;
  ScrollCode: TScrollCode; var ScrollPos: Integer);
begin
  StartX:=ScrollPos;
  Redraw;
end;

procedure TScreenShotForm.FormMouseMove(Sender: TObject;
  Shift: TShiftState; X, Y: Integer);
var MouseDown:boolean;
begin
  MouseDown:=(ssLeft IN Shift) OR (ssRight IN Shift);
  case ToolMode of
    Pick:if MouseDown then MainForm.ImportColor(Canvas.Pixels[X,Y]);
    Zoom:if MouseDown AND not(WasMouseDown) then begin
           HandBaseX:=StartX+X*ZoomDiv DIV ZoomMul;
           HandBaseY:=StartY+Y*ZoomDiv DIV ZoomMul;
           if (ssRight IN Shift) OR (ssAlt IN Shift) then begin
             dec(ZoomMul);
             if ZoomMul<1 then begin ZoomMul:=1;inc(ZoomDiv);end;
           end else begin
             dec(ZoomDiv);
             if ZoomDiv<1 then begin ZoomDiv:=1;inc(ZoomMul);end;
           end;
           StartX:=HandBaseX-X*ZoomDiv DIV ZoomMul;
             if StartX<0 then StartX:=0;
           StartY:=HandBaseY-Y*ZoomDiv DIV ZoomMul;
             if StartY<0 then StartY:=0;
           ReFit;
         end;
    Hand:if MouseDown then begin
           if WasMouseDown then begin
             StartX:=HandBaseX-X*ZoomDiv DIV ZoomMul;
               if StartX<0 then StartX:=0;
               if StartX>MaxX then StartX:=MaxX;
             StartY:=HandBaseY-Y*ZoomDiv DIV ZoomMul;
               if StartY<0 then StartY:=0;
               if StartY>MaxY then StartY:=MaxY;
             HScroll.Position:=StartX;
             VScroll.Position:=StartY;
             Redraw;
           end else begin
             HandBaseX:=StartX+X*ZoomDiv DIV ZoomMul;
             HandBaseY:=StartY+Y*ZoomDiv DIV ZoomMul;
           end;
         end; 
  end;
  WasMouseDown:=MouseDown;
end;

procedure TScreenShotForm.FormMouseDown(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  case Button of
    mbLeft: FormMouseMove(Sender,Shift+[ssLeft],X,Y);
    mbRight:FormMouseMove(Sender,Shift+[ssRight],X,Y);
  end;
end;

procedure TScreenShotForm.mHandClick(Sender: TObject);
begin
  ToolMode:=Hand;
end;

procedure TScreenShotForm.mZoomClick(Sender: TObject);
begin
  ToolMode:=Zoom;
end;

procedure TScreenShotForm.mPickClick(Sender: TObject);
begin
  ToolMode:=Pick;
end;

procedure TScreenShotForm.FormMouseUp(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  FormMouseMove(Sender,Shift-[ssLeft,ssRight],X,Y);
end;

procedure TScreenShotForm.FormKeyPress(Sender: TObject; var Key: Char);
begin
  case UpCase(Key) of
    #32:begin mHand.Down:=true; ToolMode:=Hand; end;
    'Z':begin mZoom.Down:=true; ToolMode:=Zoom; end;
    'I':begin mPick.Down:=true; ToolMode:=Pick; end;
  end;
end;

procedure TScreenShotForm.SaveImageClick(Sender: TObject);
begin
  with SaveDialog do
    if Execute then
      Shot.SaveToFile(FileName);
end;

procedure TScreenShotForm.ShowOverviewMouseDown(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
var ScreenPoint:TPoint;
begin
  ScreenPoint:=ShowOverview.ClientToScreen(Point(X,Y));
  OverviewForm.Left:=ScreenPoint.X-(ScrWidth  SHR 4)-4;
  OverviewForm.Top :=ScreenPoint.Y-(ScrHeight SHR 4)-15;
end;

procedure TScreenShotForm.ShowOverviewMouseUp(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  OverviewForm.ShowModal;
end;

end.
